import sys
from Users import Tracker
from Users import Peer
from Users import Uploader
from Users import Downloader
import socket

def main():
    print("Choose a role:")
    print("1. Tracker")
    print("2. Uploader")
    print("3. Downloader")
    print("4. Normal Peer")

    role_choice = input("Enter your choice (1/2/3/4): ")

 

    if len(sys.argv) >= 3:
        tracker_host = sys.argv[1]
        tracker_port = int(sys.argv[2])
    else:
        tracker_host = input("Please input the tracker IP address: ")
        tracker_port = int(input("Please input the tracker port number: "))

    if role_choice == "1":
        tracker = Tracker.Tracker(tracker_host, tracker_port)
        tracker.start()

    elif role_choice == "2":
        alice_instance = Uploader.uploader()

        # host = input("Please input your IP address properly: ")  # Replace with the actual IP address of the receiver machine
        # port = int(input("Please enter your port number: "))

        host = get_ip()
        port = 12345
        file_path = input("Enter the name of the file you want to upload (for default, type: test.txt): ")
        peer_id = input("Enter your peer ID: ")
        alice_instance.send_file( peer_id, host, port, tracker_host, tracker_port, file_path)
        alice_instance.connect_and_receive_response(peer_id, host, port+1, tracker_host, tracker_port)

    elif role_choice == "3":

        host = get_ip()
        port = 12345

        # host = input("Please input your IP address properly: ")  # Replace with the actual IP address of the receiver machine
        # port = int(input("Please enter your port number: "))
        peer_id = input("Enter your peer ID (any string to recognize you over network): ")
        downloader = Downloader.Downloader(peer_id, host, port, tracker_host, tracker_port)
        downloader.connect_and_receive_response()

    elif role_choice == "4":

        host = get_ip()
        port = 12345

        # host = input("Please input your IP address properly: ")  # Replace with the actual IP address of the receiver machine
        # port = int(input("Please enter your port number: "))
        peer_id = input("Enter your peer ID (any string to recognize you over network): ")
        file_handler = Peer.FileTransferHandler(peer_id, host, port, tracker_host, tracker_port)
        file_handler.connect_and_receive_response()

    else:
        print("Invalid choice. Please choose a valid option.")

def get_ip():
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    s.connect(('8.8.8.8', 1))  # connect() for UDP doesn't send packets
    return s.getsockname()[0]

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name='datakarkhana',  # Replace 'your_package' with the name of your package
    version='0.0.3',
    description='A peer-to-peer file sharing system',
    long_description='Datakarkhana is a peer-to-peer file sharing system which works on a hybrid peer-to-peer and client-server model. ',
    long_description_content_type='text/markdown',
    url='https://github.com/timsinashok/data_karkhana',  # Replace with the URL of your package repository
    author='Yaghyesh Ghimire, Manoj Dhakal, Mahmud Faisal , Ashok Timsina',  # List all authors separated by commas
    author_email='md5121@nyu.edu, yg2810@nyu.edu, fm2357@nyu.edu, ashoktimsina147181@gmail.com',  # List all author emails separated by commas
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords='peer peer-to-peer file sharing alice bob',  # Replace with keywords relevant to your package
    packages=find_packages(),
    python_requires='>=3.6, <4',
    install_requires=[],  # Add any dependencies your package requires
    entry_points = {
        'console_scripts': ['datakarkhana=data_karkhana.main:main'],
    },
    project_urls={
        'Bug Reports': 'https://github.com/timsinashok/data_karkhana/issues',  # Replace with the URL for issue tracking
        'Source': 'https://github.com/timsinashok/data_karkhana',  # Replace with the URL of your package repository
    },
)
